@@ -12,7 +12,7 @@ __PACKAGE__->columns('Blurb',   qw/ blurb/);
 sub create_sql {
 	return qq{
 			title                   VARCHAR(255) PRIMARY KEY,
-			blurb                   VARCHAR(255) NOT NULL
+			blurb                   VARCHAR(255) 
   }
 }
 
